==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notifications/l10n/zh_HK.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "我們希望繼續免費提供推送通知服務，但大量用戶使我們的基礎設施承受過重負擔。因此，我們不得不對推送通知的使用進行速率限制。如果您需要此功能，請考慮使用 Nextcloud Enterprise。",
    "User not found" : "找不到用戶",
    "An unexpected error occurred, ask your administration to check the logs." : "發生了意外錯誤，請請您的管理員檢查記錄。",
    "Hello %s" : "%s 你好",
    "Hello %s," : "%s你好，",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 有 %n 個新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %n 個關於 %s 的新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可在<a href=\"%s\">設定</a>中更改通知電郵的接收次數或停用。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "您可在設定中更改這些電郵地址的頻率或停用：%s",
    "Admin notifications" : "管理員通告",
    "Notifications" : "通告",
    "Push notifications - Fair use policy" : "推播通知 - 公平使用政策",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH 為私人用戶提供免費的推播通知通訊閘。為了確保良好的服務，通訊閘限制了每台伺服器的推播通知數量，且此伺服器已達限制。對於企業使用者來說，可以使用更具可擴充性的通訊閘。",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。\n\t\t其他應用程式使用這個 API 來通告在 Web UI 中的用戶，並同步客戶端。這裡有一些例子：\n\n📬 聯盟檔案分享：您收到了新的遠端分享\n\n📑 留言：其他用戶在檔案中的留言提及您\n\n🚢 更新通告：應用程式或 Nextcloud 自身有可用的更新\n\n📣 公告中心：管理員發佈了公告",
    "Failed to perform action" : "無法執行操作",
    "Failed to dismiss notification" : "撤銷通告失敗",
    "Dismiss" : "撤銷",
    "Contact Nextcloud GmbH" : "聯絡 Nextcloud GmbH",
    "in {path}" : "在 {path}",
    "Push notifications might be unreliable" : "推播通知可能不可靠",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH 為私人用戶贊助了一個免費的推送通知閘道。 為了確保良好的服務，閘道限制了每台服務器的推播通知數量。 對於企業用戶，可以使用更具擴展性的閘道。如需更多資訊，請聯絡 Nextcloud GmbH。",
    "Requesting browser permissions to show notifications" : "需要瀏覽器權限以顯示通告",
    "No notifications" : "沒有通告",
    "Failed to dismiss all notifications" : "撤銷所有通告失敗",
    "Dismiss all notifications" : "撤銷所有通告",
    "Never" : "從不",
    "1 hour" : "1 小時",
    "3 hours" : "3 小時",
    "1 day" : "1 日",
    "1 week" : "1 個星期",
    "Your settings have been updated." : "您的設定已更新。",
    "An error occurred while updating your settings." : "更新設置時發生錯誤",
    "Notifications defaults" : "默認通知設定",
    "Configure the default notification settings for new users" : "為新用戶配置默認通知設定",
    "Send email reminders about unhandled notifications after:" : "發送有關未處理通知的電郵提醒：",
    "Play sound when a new notification arrives" : "收到新通知時播放聲音",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時播放聲音（需要 Nextcloud Talk）",
    "None" : "無",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Also repeat sound on a secondary speaker" : "在輔助喇叭上重複播放聲音",
    "Selection of the speaker device is currently not supported by Safari" : "Safari 目前不支持選擇喇叭設備",
    "Select a device" : "選取裝置",
    "seconds ago" : "幾秒前"
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notifications/l10n/zh_HK.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "我們希望繼續免費提供推送通知服務，但大量用戶使我們的基礎設施承受過重負擔。因此，我們不得不對推送通知的使用進行速率限制。如果您需要此功能，請考慮使用 Nextcloud Enterprise。",
    "User not found" : "找不到用戶",
    "An unexpected error occurred, ask your administration to check the logs." : "發生了意外錯誤，請請您的管理員檢查記錄。",
    "Hello %s" : "%s 你好",
    "Hello %s," : "%s你好，",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 有 %n 個新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %n 個關於 %s 的新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可在<a href=\"%s\">設定</a>中更改通知電郵的接收次數或停用。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "您可在設定中更改這些電郵地址的頻率或停用：%s",
    "Admin notifications" : "管理員通告",
    "Notifications" : "通告",
    "Push notifications - Fair use policy" : "推播通知 - 公平使用政策",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH 為私人用戶提供免費的推播通知通訊閘。為了確保良好的服務，通訊閘限制了每台伺服器的推播通知數量，且此伺服器已達限制。對於企業使用者來說，可以使用更具可擴充性的通訊閘。",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。\n\t\t其他應用程式使用這個 API 來通告在 Web UI 中的用戶，並同步客戶端。這裡有一些例子：\n\n📬 聯盟檔案分享：您收到了新的遠端分享\n\n📑 留言：其他用戶在檔案中的留言提及您\n\n🚢 更新通告：應用程式或 Nextcloud 自身有可用的更新\n\n📣 公告中心：管理員發佈了公告",
    "Failed to perform action" : "無法執行操作",
    "Failed to dismiss notification" : "撤銷通告失敗",
    "Dismiss" : "撤銷",
    "Contact Nextcloud GmbH" : "聯絡 Nextcloud GmbH",
    "in {path}" : "在 {path}",
    "Push notifications might be unreliable" : "推播通知可能不可靠",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH 為私人用戶贊助了一個免費的推送通知閘道。 為了確保良好的服務，閘道限制了每台服務器的推播通知數量。 對於企業用戶，可以使用更具擴展性的閘道。如需更多資訊，請聯絡 Nextcloud GmbH。",
    "Requesting browser permissions to show notifications" : "需要瀏覽器權限以顯示通告",
    "No notifications" : "沒有通告",
    "Failed to dismiss all notifications" : "撤銷所有通告失敗",
    "Dismiss all notifications" : "撤銷所有通告",
    "Never" : "從不",
    "1 hour" : "1 小時",
    "3 hours" : "3 小時",
    "1 day" : "1 日",
    "1 week" : "1 個星期",
    "Your settings have been updated." : "您的設定已更新。",
    "An error occurred while updating your settings." : "更新設置時發生錯誤",
    "Notifications defaults" : "默認通知設定",
    "Configure the default notification settings" : "設定預設通知設定",
    "Send email reminders about unhandled notifications after:" : "發送有關未處理通知的電郵提醒：",
    "Play sound when a new notification arrives" : "收到新通知時播放聲音",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時播放聲音（需要 Nextcloud Talk）",
    "None" : "無",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Also repeat sound on a secondary speaker" : "在輔助喇叭上重複播放聲音",
    "Selection of the speaker device is currently not supported by Safari" : "Safari 目前不支持選擇喇叭設備",
    "Select a device" : "選取裝置",
    "seconds ago" : "幾秒前",
    "Configure the default notification settings for new users" : "為新用戶配置默認通知設定"
},
"nplurals=1; plural=0;");
